/////////////////////////////////////////
//	ADF4351 RF Generator		            /
//	Local-OSC.ino		                    /
//	2023-2-16 - 2023-4-4	JA4CXX	      /
/////////////////////////////////////////
//	MCU-Pin	ADF4351 Board-Pin
//	18	    CLK
//	23	    DAT
//	5	      LE
//	25	    CE
//---------------------------------------
//	Board Power	+5V
/////////////////////////////////////////
//	MCU-Pin	SSD1306 Board-Pin
//	21	    SDA
//	22	    SCL
//---------------------------------------
//	Board Power	+3.3V
/////////////////////////////////////////
//  IO26 = Bit0 pinMode(26, INPUT_PULLUP);
//  IO27 = Bit1 pinMode(27, INPUT_PULLUP);
//  Case 0 = 1990MHz
//  Case 1 = 1980MHz
//  Case 2 = 1970MHz
//  Case 3 = 1960MHz
/////////////////////////////////////////


#include "ADF4351.h"
#include <SPI.h>
#include "SSD1306.h"//ディスプレイ用ライブラリを読み込み

#define clock 18
#define data 23
#define LE 5
#define CE 25

ADF4351  adf4351(clock,data,LE,CE); // declares object PLL of type ADF4351
SSD1306  display(0x3c, 21, 22);     //SSD1306インスタンスの作成（I2Cアドレス,SDA,SCL）

void setup() {
  Serial.begin(115200);
  Serial.println("Program started!");  
  adf4351.begin();

  pinMode(26, INPUT_PULLUP);  // 入力ピン(プルアップ抵抗付)
  pinMode(27, INPUT_PULLUP);  // 入力ピン(プルアップ抵抗付)

  display.init();    //ディスプレイを初期化
  display.setFont(ArialMT_Plain_16);    //フォントを設定 ArialMT_Plain_10, ArialMT_Plain_16, ArialMT_Plain_24
  display.drawString(0, 0, "Local Oscillator");    //(0,0)の位置にWiFi connectedを表示
//  display.drawString(0, 24, "Freq: 1990MHz");
  display.drawString(0, 48, "JA4CXX");
//  display.display();   //指定された情報を描画
//  Serial.println("Freq: 2424MHz");

  int CHN = 0;
  int SW0 = digitalRead(26);
  int SW1 = digitalRead(27);

  CHN = SW0 + SW1 * 2;
  
  Serial.println("IO26=" + String(SW0));
  Serial.println("IO27=" + String(SW1));

  Serial.println("Chanel Number = " + String(CHN));

switch (CHN) {
  case 0: //1990MHz
      adf4351.WriteRegister(0x00580005);  // -R5- default value LD working mode
      adf4351.WriteRegister(0x9C803C);    // -R4- output divider = 16 // band select clock divider
      adf4351.WriteRegister(0x000004B3);  // -R3- default Antibacklash pulse width
      adf4351.WriteRegister(0x00010E42);  // -R2- Low noise mode, R Counter=4
      adf4351.WriteRegister(0x8008029);   // -R1- prescaler=4/5、 MOD=25
      adf4351.WriteRegister(0x4F8008);    // -R0- int = 128 frac = 0 
      Serial.println("All registers have benn written!");
      display.drawString(0, 24, "Freq: 1990MHz");      
      Serial.println("Freq: 1990MHz");
      display.display();   //指定された情報を描画 
    break;
  case 1: //1980MHz 
      adf4351.WriteRegister(0x00580005);  // -R5- default value LD working mode
      adf4351.WriteRegister(0x9C803C);    // -R4- output divider = 16 // band select clock divider
      adf4351.WriteRegister(0x000004B3);  // -R3- default Antibacklash pulse width
      adf4351.WriteRegister(0x00010E42);  // -R2- Low noise mode, R Counter=4
      adf4351.WriteRegister(0x8008029);   // -R1- prescaler=4/5、 MOD=25
      adf4351.WriteRegister(0x4F0010);    // -R0- int = 128 frac = 0 
      Serial.println("All registers have benn written!");
      display.drawString(0, 24, "Freq: 1980MHz");      
      Serial.println("Freq: 1980MHz");
      display.display();   //指定された情報を描画    
    break;
  case 2: //1970MHz
      adf4351.WriteRegister(0x00580005);  // -R5- default value LD working mode
      adf4351.WriteRegister(0x9C803C);    // -R4- output divider = 16 // band select clock divider
      adf4351.WriteRegister(0x000004B3);  // -R3- default Antibacklash pulse width
      adf4351.WriteRegister(0x00010E42);  // -R2- noise mode, R=4
      adf4351.WriteRegister(0x8008029);   // -R1- prescaler=4/5、 MOD=25
      adf4351.WriteRegister(0x4E8018);    // -R0- int = 128 frac = 0 
      Serial.println("All registers have benn written!");
      display.drawString(0, 24, "Freq: 1970MHz");      
      Serial.println("Freq: 1970MHz");
      display.display();   //指定された情報を描画                 
    break;
  case 3: //1960MHz
      adf4351.WriteRegister(0x00580005);  // -R5- default value LD working mode
      adf4351.WriteRegister(0x9C803C);    // -R4- output divider = 16 // band select clock divider
      adf4351.WriteRegister(0x000004B3);  // -R3- default Antibacklash pulse width
      adf4351.WriteRegister(0x00010E42);  // -R2- noise mode, R=4
      adf4351.WriteRegister(0x8008029);   // -R1- prescaler=4/5、 MOD=25
      adf4351.WriteRegister(0x4E0020);    // -R0- int = 128 frac = 0 
      Serial.println("All registers have benn written!");
      display.drawString(0, 24, "Freq: 1960MHz");      
      Serial.println("Freq: 1960MHz");
      display.display();   //指定された情報を描画    
    break;    
  default:
    // どのcaseにも一致しなかったとき実行される
    // (defaultは省略可能)
    break;
  }  

/*
// ref = 100MHz RFout = 1990MHz
  adf4351.WriteRegister(0x00580005);  // -R5- default value LD working mode
  adf4351.WriteRegister(0x9C803C);    // -R4- output divider = 16 // band select clock divider
  adf4351.WriteRegister(0x000004B3);  // -R3- default Antibacklash pulse width
  adf4351.WriteRegister(0x00010E42);  // -R2- noise mode, R=4
  adf4351.WriteRegister(0x8008029);   // -R1- prescaler=4/5、 MOD=25
  adf4351.WriteRegister(0x4F8008);    // -R0- int = 128 frac = 0

 
// ref = 100MHz RFout = 2424MHz
  adf4351.WriteRegister(0x00580005);  // -R5- default value LD working mode
  adf4351.WriteRegister(0x8C803C);    // -R4- output divider = 16 // band select clock divider
  adf4351.WriteRegister(0x000004B3);  // -R3- default Antibacklash pulse width
  adf4351.WriteRegister(0x00010E42);  // -R2- noise mode, R=4
  adf4351.WriteRegister(0x80080C9);   // -R1- prescaler=4/5、 MOD=25
  adf4351.WriteRegister(0x3000C0);    // -R0- int = 128 frac = 0
  
  Serial.println("All registers have benn written!");
*/
}

void loop() {
  // put your main code here, to run repeatedly:  
}